# Core Developers #

----------
- Mohammad Mahdi Rahimi - Amirkabir University Of Technology - ([https://github.com/mahi97](https://github.com/mahi97)) ([mahi@ecsim.ir](mailto:mahi@ecsim.ir))
- Sepand Haghighi - Sharif University Of Technology/Moduland Co - ([http://github.com/sepandhaghighi](http://github.com/sepandhaghighi)) ([sepand@ecsim.ir](mailto:sepand@ecsim.ir))
- Sarmin Hamidi - University Of Tehran - ([https://github.com/sarminh](https://github.com/sarminh)) ([sarmin@ecsim.ir](mailto:sarmin@ecsim.ir))
- Kasra Askari - Isfahan University Of Technology - ([https://github.com/kasraaskari](https://github.com/kasraaskari)) ([kasra@ecsim.ir](mailto:kasra@ecsim.ir))
